@@ -71,6 +71,12 @@ GlyphCache::GlyphCache( GlyphCachePeer& rPeer )
 GlyphCache::~GlyphCache()
 {
     InvalidateAllGlyphs();
+    for( FontList::iterator it = maFontList.begin(), end = maFontList.end(); it != end; ++it )
+    {
+        ServerFont* pServerFont = it->second;
+        mrPeer.RemovingFont(*pServerFont);
+        delete pServerFont;
+    }
     if( mpFtManager )
         delete mpFtManager;
 }
@@ -79,6 +85,18 @@ GlyphCache::~GlyphCache()
 
 void GlyphCache::InvalidateAllGlyphs()
 {
+    // an application about to exit can omit garbage collecting the heap
+    // since it makes things slower and introduces risks if the heap was not perfect
+    // for debugging, for memory grinding or leak checking the env allows to force GC
+    const char* pEnv = getenv( "SAL_FORCE_GC_ON_EXIT" );
+    if( pEnv && (*pEnv != '0') )
+    {
+        // uncache of all glyph shapes and metrics
+        for( FontList::iterator it = maFontList.begin(); it != maFontList.end(); ++it )
+            delete const_cast<ServerFont*>( it->second );
+        maFontList.clear();
+        mpCurrentGCFont = NULL;
+    }
 }
 
 // -----------------------------------------------------------------------
@@ -283,9 +301,9 @@ void GlyphCache::UncacheFont( ServerFont& rServerFont )
 
 // -----------------------------------------------------------------------
 
-ULONG GlyphCache::CalcByteCount() const
+sal_uLong GlyphCache::CalcByteCount() const
 {
-    ULONG nCacheSize = sizeof(*this);
+    sal_uLong nCacheSize = sizeof(*this);
     for( FontList::const_iterator it = maFontList.begin(); it != maFontList.end(); ++it )
     {
         const ServerFont* pSF = it->second;
@@ -331,7 +349,7 @@ void GlyphCache::GarbageCollect()
         pServerFont->GarbageCollect( mnLruIndex+0x10000000 );
         if( pServerFont == mpCurrentGCFont )
             mpCurrentGCFont = NULL;
-    const ImplFontSelectData& rIFSD = pServerFont->GetFontSelData();
+        const ImplFontSelectData& rIFSD = pServerFont->GetFontSelData();
         maFontList.erase( rIFSD );
         mrPeer.RemovingFont( *pServerFont );
         mnBytesUsed -= pServerFont->GetByteCount();
@@ -517,7 +535,6 @@ ImplServerFontEntry::ImplServerFontEntry( ImplFontSelectData& rFSD )
 :   ImplFontEntry( rFSD )
 ,   mpServerFont( NULL )
 ,   mbGotFontOptions( false )
-,   mbValidFontOptions( false )
 {}
 
 // -----------------------------------------------------------------------
